@@ -40,7 +40,7 @@ class Snowbank():
         cursor.execute(queries.get_last_row_id())
         id = cursor.fetchall()[0][0]
         cursor.close()
-        currFlake = flake.FlurryFlake(id, actions)
+        currFlake = flake.FlurryFlake(id, action)
         self.client.user_data_set({'graph': currFlake})
         return currFlake
 
